<?php
/* --------------------------------------------------------------
 AdminServiceProviderRegistration.php 2020-08-11
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Application\Bootstrapper;

use Gambio\Admin\Application\Registry\ProviderRegistry\Services\ProviderRegistryService;
use Gambio\Admin\Application\Registry\RegistryServiceProvider;
use Gambio\Admin\Application\Token\TokenServiceProvider;
use Gambio\Admin\Application\ErrorHandling\AdminErrorServiceProvider;
use Gambio\Admin\Application\Http\AdminHttpServiceProvider;
use Gambio\Admin\Layout\Favorites\FavoritesServiceProvider;
use Gambio\Admin\Layout\Menu\AdminMenuServiceProvider;
use Gambio\Admin\Layout\Renderer\AdminRendererServiceProvider;
use Gambio\Core\Application\Contracts\Application;
use Gambio\Core\Application\Contracts\Bootstrapper;

/**
 * Class AdminServiceProviderRegistration
 * @package Gambio\Admin\Application\Kernel\Bootstrapper
 */
class AdminServiceProviderRegistration implements Bootstrapper
{
    private const CORE_SERVICE_PROVIDERS = [
        RegistryServiceProvider::class,
        FavoritesServiceProvider::class,
        AdminRendererServiceProvider::class,
        AdminMenuServiceProvider::class,
        AdminHttpServiceProvider::class,
        TokenServiceProvider::class,
        AdminErrorServiceProvider::class,
    ];
    
    
    /**
     * @inheritDoc
     */
    public function boot(Application $application): void
    {
        $this->registerCoreServiceProvider($application);
        
        $registryService = $this->getRegistryService($application);
        if ($registryService) {
            $registry = $registryService->getRegistry();
            $this->registerServiceProviders($registry->serviceProviders(), $application);
        }
    }
    
    
    /**
     * Returns the service provider registry service.
     *
     * @param Application $application
     *
     * @return ProviderRegistryService|null
     */
    private function getRegistryService(Application $application): ?ProviderRegistryService
    {
        return $application->has(ProviderRegistryService::class) ? $application->get(
            ProviderRegistryService::class
        ) : null;
    }
    
    
    /**
     * Registers all of the core admin service providers.
     *
     * @param Application $application
     */
    private function registerCoreServiceProvider(Application $application): void
    {
        $this->registerServiceProviders(self::CORE_SERVICE_PROVIDERS, $application);
    }
    
    
    /**
     * Tries to register service providers by using the provided list.
     * This method silently continues if anything fails on the registration process.
     *
     * @param array       $serviceProviders
     * @param Application $application
     */
    private function registerServiceProviders(array $serviceProviders, Application $application): void
    {
        foreach ($serviceProviders as $provider) {
            $application->registerProvider($provider);
        }
    }
}