<?php
/* --------------------------------------------------------------
 RouteRegistration.php 2020-09-15
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Application\Bootstrapper;

use Gambio\Core\Application\Contracts\Application;
use Gambio\Core\Application\Contracts\Bootstrapper;
use RuntimeException;
use Slim\App;

/**
 * Class RouteRegistration
 * @package Gambio\Admin\Application\Bootstrapper
 */
class RouteRegistration implements Bootstrapper
{
    /**
     * @inheritDoc
     */
    public function boot(Application $application): void
    {
        $slim = $this->getSlimApp($application);
        
        $pattern = dirname(__DIR__, 2) . '/Modules/*/routes.php';
        $files   = glob($pattern);
        
        foreach ($files as $file) {
            /** @noinspection PhpIncludeInspection */
            $registerCallback = require $file;
            if (is_callable($registerCallback)) {
                $registerCallback($slim);
            }
        }
    }
    
    
    /**
     * Returns a slim application instance.
     *
     * @param Application $application
     *
     * @return App
     */
    private function getSlimApp(Application $application): App
    {
        if (!$application->has(App::class)) {
            throw new RuntimeException('Slim must be bootstrapped before this bootstrapper');
        }
        
        return $application->get(App::class);
    }
}