<?php
/* --------------------------------------------------------------
 AdminErrorServiceProvider.php 2020-05-29
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Application\ErrorHandling;

use Gambio\Admin\Layout\Renderer\GambioAdminRenderer;
use Gambio\Core\Application\DependencyInjection\AbstractServiceProvider;
use Gambio\Core\Application\ValueObjects\UserPreferences;
use Gambio\Core\Language\TextManager;
use Psr\Http\Message\ResponseFactoryInterface;
use Slim\Interfaces\CallableResolverInterface;

/**
 * Class AdminErrorServiceProvider
 * @package Gambio\Admin\Application\ErrorHandling
 */
class AdminErrorServiceProvider extends AbstractServiceProvider
{
    /**
     * @inheritDoc
     */
    public function provides(): array
    {
        return [
            AdminErrorHandler::class,
            AdminExceptionHandler::class,
        ];
    }
    
    
    /**
     * @inheritDoc
     */
    public function register(): void
    {
        $this->application->registerShared(AdminErrorHandler::class);
        
        $this->application->registerShared(AdminExceptionHandler::class)
                          ->addArgument(CallableResolverInterface::class)
                          ->addArgument(ResponseFactoryInterface::class)
                          ->addArgument(GambioAdminRenderer::class)
                          ->addArgument(TextManager::class)
                          ->addArgument(UserPreferences::class);
    }
}