<?php
/* --------------------------------------------------------------
 MiddlewareServiceProvider.php 2020-10-05
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Application\Middleware;

use Doctrine\DBAL\Connection;
use Gambio\Admin\Modules\Customer\SimpleCustomerService;
use Gambio\Admin\Modules\DSGVO\Services\DSGVOService;
use Gambio\Core\AdminAccess\PermissionService;
use Gambio\Core\Application\DependencyInjection\AbstractServiceProvider;
use Gambio\Core\Application\ValueObjects\Path;
use Gambio\Core\Application\ValueObjects\Url;
use Gambio\Core\Application\ValueObjects\UserPreferences;
use Gambio\Core\Configuration\Builder\ConfigurationFinderBuilder;

/**
 * Class MiddlewareServiceProvider
 * @package Gambio\Admin\Application\Middleware
 */
class MiddlewareServiceProvider extends AbstractServiceProvider
{
    /**
     * @inheritDoc
     */
    public function provides(): array
    {
        return [
            AuthMiddleware::class,
            SecurityHeadersMiddleware::class,
            AdminActivityLogMiddleware::class,
            UpdaterRedirectMiddleware::class,
        ];
    }
    
    
    /**
     * @inheritDoc
     */
    public function register(): void
    {
        $authArgs = [
            SimpleCustomerService::class,
            UserPreferences::class,
            Url::class,
            PermissionService::class,
        ];
        $this->application->registerShared(AuthMiddleware::class)->addArguments($authArgs);
        
        $this->application->registerShared(SecurityHeadersMiddleware::class)
            ->addArgument(ConfigurationFinderBuilder::class);
        
        $this->application->registerShared(AdminActivityLogMiddleware::class)->addArgument(DSGVOService::class);
        
        $this->registerUpdaterRedirectMiddleware();
    }
    
    
    private function registerUpdaterRedirectMiddleware(): void
    {
        $dependencies = [
            Connection::class,
            Url::class,
            Path::class,
        ];
        $this->application->registerShared(UpdaterRedirectMiddleware::class)->addArguments($dependencies);
    }
}