<?php
/* --------------------------------------------------------------
 ClearRegistryCache.php 2020-09-18
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Application\Registry\CommandHandlers;

use Gambio\Admin\Application\Registry\Commands\ClearRegistryCache as Command;
use Gambio\Admin\Application\Registry\ModuleRegistry\Services\ModuleRegistryCache;
use Gambio\Admin\Application\Registry\ProviderRegistry\Services\ProviderRegistryCache;

class ClearRegistryCache
{
    /**
     * @var ProviderRegistryCache
     */
    private $providerRegistryCache;
    
    /**
     * @var ModuleRegistryCache
     */
    private $moduleRegistryCache;
    
    
    /**
     * ClearRegistryCache constructor.
     *
     * @param ProviderRegistryCache $providerRegistryCache
     * @param ModuleRegistryCache   $moduleRegistryCache
     */
    public function __construct(ProviderRegistryCache $providerRegistryCache, ModuleRegistryCache $moduleRegistryCache)
    {
        $this->providerRegistryCache = $providerRegistryCache;
        $this->moduleRegistryCache   = $moduleRegistryCache;
    }
    
    
    /**
     * Clears the registry caches.
     *
     * @param Command $command
     *
     * @return Command
     */
    public function __invoke(Command $command): Command
    {
        $this->providerRegistryCache->deleteRegistry();
        $this->moduleRegistryCache->deleteRegistry();
        
        return $command;
    }
}