<?php
/* --------------------------------------------------------------
 ModuleRegistryCache.php 2020-09-17
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Application\Registry\ModuleRegistry\App\Data;

use Gambio\Admin\Application\Registry\ModuleRegistry\Model\ModuleRegistry;
use Gambio\Admin\Application\Registry\ModuleRegistry\Model\ValueObject\ModuleRegistry as Registry;
use Gambio\Admin\Application\Registry\ModuleRegistry\Services\ModuleRegistryCache as RegistryCache;
use Gambio\Admin\Application\Registry\ModuleRegistry\Services\ModuleRegistryRepository as RegistryRepository;
use Gambio\Core\Cache\CacheFactory;
use Gambio\Core\Cache\SafeCache;
use Psr\SimpleCache\InvalidArgumentException;

/**
 * Class ModuleRegistryCache
 * @package Gambio\Admin\Application\Registry\ModuleRegistry\App\Data
 */
class ModuleRegistryCache implements RegistryCache
{
    private const CACHE_KEY = 'module_registry';
    
    use SafeCache;
    
    /**
     * @var RegistryRepository
     */
    private $registryRepository;
    
    
    /**
     * ModuleRegistryCache constructor.
     *
     * @param RegistryRepository $registryRepository
     *
     * @param CacheFactory       $cacheFactory
     *
     * @throws InvalidArgumentException
     */
    public function __construct(RegistryRepository $registryRepository, CacheFactory $cacheFactory)
    {
        $this->registryRepository = $registryRepository;
        $this->cache              = $cacheFactory->createCacheFor(self::CACHE_KEY);
    }
    
    
    /**
     * @inheritDoc
     */
    public function getRegistry(): ModuleRegistry
    {
        if ($this->safeHas(self::CACHE_KEY)) {
            $data = $this->safeGet(self::CACHE_KEY);
            
            return new Registry(
                $data['modules'] ?? [], $data['serviceProviders'] ?? [], $data['autoloaderPaths'] ?? []
            );
        }
        $registry = $this->registryRepository->getRegistry();
        $data     = [
            'modules'          => $registry->modules(),
            'serviceProviders' => $registry->serviceProviders(),
            'autoloaderPaths'  => $registry->autoloaderPaths(),
        ];
        $this->safeSet(self::CACHE_KEY, $data);
        
        return $registry;
    }
    
    
    /**
     * @inheritDoc
     */
    public function deleteRegistry(): void
    {
        $this->safeDelete(self::CACHE_KEY);
    }
}