<?php
/* --------------------------------------------------------------
 ModuleRegistryService.php 2020-09-17
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Application\Registry\ModuleRegistry\App;

use Gambio\Admin\Application\Registry\ModuleRegistry\Model\ModuleRegistry;
use Gambio\Admin\Application\Registry\ModuleRegistry\Services\ModuleRegistryCache;
use Gambio\Admin\Application\Registry\ModuleRegistry\Services\ModuleRegistryRepository;
use Gambio\Admin\Application\Registry\ModuleRegistry\Services\ModuleRegistryService as RegistryService;
use Gambio\Core\Application\ValueObjects\Environment;

/**
 * Class ModuleRegistryService
 * @package Gambio\Admin\Application\Registry\ModuleRegistry\App
 */
class ModuleRegistryService implements RegistryService
{
    /**
     * @var ModuleRegistryCache
     */
    private $registryCache;
    
    /**
     * @var ModuleRegistryRepository
     */
    private $registryRepository;
    
    /**
     * @var Environment
     */
    private $environment;
    
    /**
     * @var ModuleRegistry|null
     */
    private $registry;
    
    
    /**
     * ModuleRegistryService constructor.
     *
     * @param ModuleRegistryCache      $registryCache
     * @param ModuleRegistryRepository $registryRepository
     * @param Environment              $environment
     */
    public function __construct(
        ModuleRegistryCache $registryCache,
        ModuleRegistryRepository $registryRepository,
        Environment $environment
    ) {
        $this->registryCache      = $registryCache;
        $this->registryRepository = $registryRepository;
        $this->environment        = $environment;
    }
    
    
    /**
     * @inheritDoc
     */
    public function getRegistry(): ModuleRegistry
    {
        if (null === $this->registry) {
            $this->registry = $this->fetchRegistry();
        }
        
        return $this->registry;
    }
    
    
    /**
     * Fetches module registry information.
     *
     * @return ModuleRegistry
     */
    private function fetchRegistry(): ModuleRegistry
    {
        if ($this->environment->isDev()) {
            return $this->registryRepository->getRegistry();
        }
        
        return $this->registryCache->getRegistry();
    }
}