<?php
/* --------------------------------------------------------------
 ProviderRegistryCache.php 2020-09-18
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Application\Registry\ProviderRegistry\App\Data;

use Gambio\Admin\Application\Registry\ProviderRegistry\Model\ProviderRegistry;
use Gambio\Admin\Application\Registry\ProviderRegistry\Model\ValueObject\ProviderRegistry as Registry;
use Gambio\Admin\Application\Registry\ProviderRegistry\Services\ProviderRegistryCache as RegistryCache;
use Gambio\Admin\Application\Registry\ProviderRegistry\Services\ProviderRegistryRepository;
use Gambio\Core\Cache\CacheFactory;
use Gambio\Core\Cache\SafeCache;
use Psr\SimpleCache\InvalidArgumentException;

/**
 * Class ProviderRegistryCache
 * @package Gambio\Admin\Application\Registry\ProviderRegistry\App\Data
 */
class ProviderRegistryCache implements RegistryCache
{
    private const CACHE_KEY = 'provider_registry';
    
    use SafeCache;
    
    /**
     * @var ProviderRegistryRepository
     */
    private $registryRepository;
    
    
    /**
     * ProviderRegistryCache constructor.
     *
     * @param ProviderRegistryRepository $registryRepository
     * @param CacheFactory               $cacheFactory
     *
     * @throws InvalidArgumentException
     */
    public function __construct(ProviderRegistryRepository $registryRepository, CacheFactory $cacheFactory)
    {
        $this->registryRepository = $registryRepository;
        $this->cache              = $cacheFactory->createCacheFor(self::CACHE_KEY);
    }
    
    
    /**
     * @inheritDoc
     */
    public function getRegistry(): ProviderRegistry
    {
        if ($this->safeHas(self::CACHE_KEY)) {
            $provider = $this->safeGet(self::CACHE_KEY);
            
            return new Registry($provider);
        }
        
        $registry = $this->registryRepository->getRegistry();
        $this->safeSet(self::CACHE_KEY, $registry->serviceProviders());
        
        return $registry;
    }
    
    
    /**
     * @inheritDoc
     */
    public function deleteRegistry(): void
    {
        $this->safeDelete(self::CACHE_KEY);
    }
}