<?php
/* --------------------------------------------------------------
 ProviderRegistryRepository.php 2020-09-18
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Application\Registry\ProviderRegistry\App\Data;

use Gambio\Admin\Application\Registry\ProviderRegistry\Model\ProviderRegistry;
use Gambio\Admin\Application\Registry\ProviderRegistry\Model\ValueObject\ProviderRegistry as Registry;
use Gambio\Admin\Application\Registry\ProviderRegistry\Services\ProviderRegistryRepository as RegistryRepository;
use Gambio\Core\Application\ValueObjects\Path;
use RecursiveDirectoryIterator;
use RecursiveIteratorIterator;
use SplFileInfo;

/**
 * Class ProviderRegistryRepository
 * @package Gambio\Admin\Application\Registry\ProviderRegistry\App\Data
 * @codeCoverageIgnore
 */
class ProviderRegistryRepository implements RegistryRepository
{
    /**
     * @var Path
     */
    private $path;
    
    
    /**
     * ProviderRegistryRepository constructor.
     *
     * @param Path $path
     */
    public function __construct(Path $path)
    {
        $this->path = $path;
    }
    
    
    /**
     * @inheritDoc
     */
    public function getRegistry(): ProviderRegistry
    {
        $adminModules     = "{$this->path->base()}/GambioAdmin/Modules";
        $serviceProviders = [];
        
        foreach ($this->recursiveDirectoryIterator($adminModules) as $fileInfo) {
            $filename = $fileInfo->getFilename();
            
            if ($this->endsWith('ServiceProvider.php', $filename)) {
                $path               = $fileInfo->getPathname();
                $serviceProviders[] = 'Gambio\Admin\\' . str_replace(
                        ["{$this->path->base()}/GambioAdmin/", '.php', '/'],
                        ['', '', '\\'],
                        $path
                    );
            }
        }
        
        return new Registry($serviceProviders);
    }
    
    
    /**
     * Checks if subject ends with expected string.
     *
     * @param string $searchFor
     * @param string $subject
     *
     * @return bool
     */
    private function endsWith(string $searchFor, string $subject): bool
    {
        $length = strlen($searchFor);
        if ($length === 0) {
            return true;
        }
        
        return (substr($subject, -$length) === $searchFor);
    }
    
    
    /**
     * Utility method to create a recursive directory iterator.
     *
     * @param string $path
     *
     * @return RecursiveIteratorIterator|SplFileInfo[]
     */
    private function recursiveDirectoryIterator(string $path): RecursiveIteratorIterator
    {
        return new RecursiveIteratorIterator(
            new RecursiveDirectoryIterator(
                $path, RecursiveDirectoryIterator::SKIP_DOTS
            ), RecursiveIteratorIterator::LEAVES_ONLY
        );
    }
}