<?php
/* --------------------------------------------------------------
 ProviderRegistryService.php 2020-09-18
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Application\Registry\ProviderRegistry\App;

use Gambio\Admin\Application\Registry\ProviderRegistry\Model\ProviderRegistry;
use Gambio\Admin\Application\Registry\ProviderRegistry\Services\ProviderRegistryCache;
use Gambio\Admin\Application\Registry\ProviderRegistry\Services\ProviderRegistryRepository;
use Gambio\Admin\Application\Registry\ProviderRegistry\Services\ProviderRegistryService as RegistryService;
use Gambio\Core\Application\ValueObjects\Environment;

/**
 * Class ProviderRegistryService
 * @package Gambio\Admin\Application\Registry\ProviderRegistry\App
 */
class ProviderRegistryService implements RegistryService
{
    /**
     * @var ProviderRegistryCache
     */
    private $registryCache;
    /**
     * @var ProviderRegistryRepository
     */
    private $registryRepository;
    /**
     * @var Environment
     */
    private $environment;
    
    /**
     * @var ProviderRegistry|null
     */
    private $registry;
    
    
    /**
     * ProviderRegistryService constructor.
     *
     * @param ProviderRegistryCache      $registryCache
     * @param ProviderRegistryRepository $registryRepository
     * @param Environment                $environment
     */
    public function __construct(
        ProviderRegistryCache $registryCache,
        ProviderRegistryRepository $registryRepository,
        Environment $environment
    ) {
        $this->registryCache      = $registryCache;
        $this->registryRepository = $registryRepository;
        $this->environment        = $environment;
    }
    
    
    /**
     * @inheritDoc
     */
    public function getRegistry(): ProviderRegistry
    {
        if (null === $this->registry) {
            $this->registry = $this->fetchRegistry();
        }
        
        return $this->registry;
    }
    
    
    /**
     * Fetches the provider registry.
     *
     * @return ProviderRegistry
     */
    private function fetchRegistry(): ProviderRegistry
    {
        if ($this->environment->isDev()) {
            return $this->registryRepository->getRegistry();
        }
        
        return $this->registryCache->getRegistry();
    }
}