<?php
/* --------------------------------------------------------------
 RegistryServiceProvider.php 2020-09-18
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Application\Registry;

use Gambio\Admin\Application\Registry\ModuleRegistry\App\CommandHandlers\RegisterGXModules;
use Gambio\Admin\Application\Registry\ModuleRegistry\App\CommandHandlers\RegisterGxModulesProvider;
use Gambio\Core\Application\DependencyInjection\AbstractBootableServiceProvider;
use Gambio\Core\Application\Modules\App\Commands\SearchModules;
use Gambio\Core\Application\Modules\App\Commands\SearchServiceProvider;
use Gambio\Core\Application\ValueObjects\Environment;
use Gambio\Core\Application\ValueObjects\Path;
use Gambio\Core\Cache\CacheFactory;

/**
 * Class RegistryServiceProvider
 * @package Gambio\Admin\Application\Registry
 */
class RegistryServiceProvider extends AbstractBootableServiceProvider
{
    /**
     * @inheritDoc
     */
    public function provides(): array
    {
        return [
            ProviderRegistry\Services\ProviderRegistryService::class,
            
            ModuleRegistry\App\CommandHandlers\RegisterGXModules::class,
            ModuleRegistry\App\CommandHandlers\RegisterGxModulesProvider::class,
            ModuleRegistry\Services\ModuleRegistryService::class
        ];
    }
    
    
    /**
     * @inheritDoc
     */
    public function boot(): void
    {
        $this->application->attachCommandHandler(
            Commands\ClearRegistryCache::class,
            CommandHandlers\ClearRegistryCache::class
        );
        $this->application->attachCommandHandler(SearchModules::class, RegisterGXModules::class);
        $this->application->attachCommandHandler(SearchServiceProvider::class, RegisterGxModulesProvider::class);
    }
    
    
    /**
     * @inheritDoc
     */
    public function register(): void
    {
        $this->registerProviderRegistry();
        $this->registerModuleRegistry();
    }
    
    
    public function registerProviderRegistry(): void
    {
        $this->application->registerShared(
            ProviderRegistry\Services\ProviderRegistryService::class,
            ProviderRegistry\App\ProviderRegistryService::class
        )->addArguments(
            [
                ProviderRegistry\Services\ProviderRegistryCache::class,
                ProviderRegistry\Services\ProviderRegistryRepository::class,
                Environment::class
            ]
        );
        $this->application->registerShared(
            ProviderRegistry\Services\ProviderRegistryCache::class,
            ProviderRegistry\App\Data\ProviderRegistryCache::class
        )->addArguments([ProviderRegistry\Services\ProviderRegistryRepository::class, CacheFactory::class]);
        $this->application->registerShared(
            ProviderRegistry\Services\ProviderRegistryRepository::class,
            ProviderRegistry\App\Data\ProviderRegistryRepository::class
        )->addArgument(Path::class);
    }
    
    
    public function registerModuleRegistry(): void
    {
        $this->application->registerShared(ModuleRegistry\App\CommandHandlers\RegisterGXModules::class)->addArgument(
            ModuleRegistry\Services\ModuleRegistryService::class
        );
        $this->application->registerShared(ModuleRegistry\App\CommandHandlers\RegisterGxModulesProvider::class)
                          ->addArgument(
                              ModuleRegistry\Services\ModuleRegistryService::class
                          );
        
        $this->application->registerShared(
            ModuleRegistry\Services\ModuleRegistryService::class,
            ModuleRegistry\App\ModuleRegistryService::class
        )->addArguments(
            [
                ModuleRegistry\Services\ModuleRegistryCache::class,
                ModuleRegistry\Services\ModuleRegistryRepository::class,
                Environment::class
            ]
        );
        
        $this->application->registerShared(
            ModuleRegistry\Services\ModuleRegistryCache::class,
            ModuleRegistry\App\Data\ModuleRegistryCache::class
        )->addArguments([ModuleRegistry\Services\ModuleRegistryRepository::class, CacheFactory::class]);
        
        $this->application->registerShared(
            ModuleRegistry\Services\ModuleRegistryRepository::class,
            ModuleRegistry\App\Data\ModuleRegistryRepository::class
        )->addArguments([ModuleRegistry\App\Data\GxModulesPaths::class, Path::class]);
        
        $this->application->registerShared(ModuleRegistry\App\Data\GxModulesPaths::class)->addArgument(Path::class);
    }
}