<?php
/* --------------------------------------------------------------
 GambioAdminLoader.php 2020-09-03
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Layout\Renderer;

use Gambio\Core\Command\Interfaces\CommandDispatcher;
use Gambio\Core\TemplateEngine\Commands\LoadAdminLayout;
use Gambio\Core\TemplateEngine\Loader;
use Gambio\Core\TemplateEngine\LayoutData;
use Throwable;
use function Gambio\Core\Logging\logger;

/**
 * Class GambioAdminLoader
 * @package Gambio\Admin\Layout\Renderer
 */
class GambioAdminLoader implements Loader
{
    /**
     * @var CommandDispatcher
     */
    private $commandDispatcher;

    /**
     * @var Loader[]
     */
    private $loaders = [];


    /**
     * TemplateDataLoader constructor.
     *
     * @param CommandDispatcher $commandDispatcher
     * @param Loader            ...$loaders
     */
    public function __construct(CommandDispatcher $commandDispatcher, Loader ...$loaders)
    {
        $this->commandDispatcher = $commandDispatcher;
        foreach ($loaders as $loader) {
            $this->loaders[get_class($loader)] = $loader;
        }
    }


    /**
     * @param Loader $loader
     */
    public function addLoader(Loader $loader): void
    {
        $this->loaders[get_class($loader)] = $loader;
    }


    /**
     * @inheritDoc
     */
    public function load(LayoutData $data): void
    {
        $command = new LoadAdminLayout();
        $this->commandDispatcher->dispatch($command);
        $loaders = array_merge($this->loaders, $command->loaders());

        foreach ($loaders as $loader) {
            try {
                $loader->load($data);
            } catch (Throwable $t) {
                logger()->error(
                    'Template loader failed',
                    ['message' => $t->getMessage(), 'file' => $t->getFile(), 'line' => $t->getLine()]
                );
            }
        }
    }
}