<?php
/* --------------------------------------------------------------
 ConfigurationOverview.php 2020-09-15
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Modules\Configuration\App\Actions;

use Gambio\Admin\Application\Http\VuePageAction;
use Gambio\Admin\Modules\Configuration\Services\Interfaces\CategoryRepositoryInterface;
use Gambio\Admin\Modules\Configuration\Services\Interfaces\ListingCategoryRepositoryInterface;
use Gambio\Admin\Modules\Configuration\Services\Interfaces\TagRepositoryInterface;
use Gambio\Core\Application\Modules\Http\Response as HttpResponse;

/**
 * Class ConfigurationOverview
 * @package Gambio\Admin\Modules\Configuration\App\Actions
 */
class ConfigurationOverview extends VuePageAction
{
    /**
     * @var ListingCategoryRepositoryInterface
     */
    private $listingCategoryRepository;
    
    /**
     * @var CategoryRepositoryInterface
     */
    private $categoryRepository;
    
    /**
     * @var TagRepositoryInterface
     */
    private $tagRepository;
    
    
    /**
     * ConfigurationController constructor.
     *
     * @param ListingCategoryRepositoryInterface $listingCategoryRepository
     * @param CategoryRepositoryInterface        $categoryRepository
     * @param TagRepositoryInterface             $tagRepository
     */
    public function __construct(
        ListingCategoryRepositoryInterface $listingCategoryRepository,
        CategoryRepositoryInterface $categoryRepository,
        TagRepositoryInterface $tagRepository
    ) {
        $this->listingCategoryRepository = $listingCategoryRepository;
        $this->categoryRepository        = $categoryRepository;
        $this->tagRepository             = $tagRepository;
    }
    
    
    /**
     * @inheritDoc
     */
    protected function handle(): HttpResponse
    {
        $this->enableLargePageLayout();
        $data = [
            'categories' => $this->categoryRepository->getAllCategories(),
            'tags'       => $this->tagRepository->getAllTags(),
            'data'       => $this->listingCategoryRepository->getAllListingCategories(),
        ];
        $data = json_encode($data);
        $data = htmlspecialchars($data);
        $data = ['configurations' => $data];
        
        $this->addVuePageTranslation('title', 'configuration_page');
        $this->addVuePageTranslation('categories', 'categories_title', 'configuration_page');
        $this->addVuePageTranslation('tags', 'tags_title', 'configuration_page');
        $this->addVuePageTranslation('save', 'save_btn_title', 'configuration_page');
        $this->addVuePageTranslation('search_placeholder', 'configuration_page');
        $this->addVuePageTranslation('selected', 'admin_labels');
        $this->addVuePageTranslation('select', 'admin_labels');
        $this->addVuePageTranslation('deselect', 'admin_labels');
        
        $template = $this->render(
            $this->translate('page_title', 'configuration_page'),
            __DIR__ . '/../../ui/configuration_page.html',
            $data
        );
        
        return $this->response->write($template);
    }
    
    
    /**
     * @inheritDoc
     */
    protected function jsEntrypoint(): string
    {
        return 'configuration';
    }
}