<?php
/* --------------------------------------------------------------
 StoreConfiguration.php 2020-09-21
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Modules\Configuration\App\Actions;

use Gambio\Core\Application\Modules\Http\Response as HttpResponse;
use Gambio\Core\Application\Modules\ModuleAction;
use Gambio\Core\Configuration\ConfigurationService;
use Gambio\Core\Configuration\Models\Write\Configuration;
use Throwable;
use Webmozart\Assert\Assert;

/**
 * Class StoreConfiguration
 * @package Gambio\Admin\Modules\Configuration\App\Actions
 */
class StoreConfiguration extends ModuleAction
{
    /**
     * @var ConfigurationService
     */
    private $configurationService;
    
    
    /**
     * StoreConfiguration constructor.
     *
     * @param ConfigurationService $configurationService
     */
    public function __construct(ConfigurationService $configurationService)
    {
        $this->configurationService = $configurationService;
    }
    
    
    /**
     * @inheritDoc
     */
    protected function handle(): HttpResponse
    {
        try {
            $configurations = $this->request->getParsedBody()['configurations'] ?? [];
            Assert::isMap($configurations);
            
            foreach ($configurations as $key => $newValue) {
                $this->configurationService->save(Configuration::create($key, $newValue));
            }
            
            return $this->response->withJson(['success' => true]);
        } catch (Throwable $exception) {
            return $this->response->withJson(['success' => false, 'error' => $exception->getMessage()]);
        }
    }
}