<?php
/* --------------------------------------------------------------
   Tags.php 2020-08-18
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2020 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\Configuration\Model\Collections;

use ArrayIterator;
use Gambio\Admin\Modules\Configuration\Model\Entities\Tag;
use IteratorAggregate;
use JsonSerializable;

/**
 * Class Tags
 *
 * @package Gambio\Admin\Modules\Configuration\Model\Collections
 */
class Tags implements JsonSerializable, IteratorAggregate
{
    /**
     * @var Tag[]
     */
    private $tags;
    
    
    /**
     * Tags constructor.
     *
     * @param Tag[] $tags
     */
    private function __construct(Tag ...$tags)
    {
        $this->tags = $tags;
    }
    
    
    /**
     * @param Tag ...$tags
     *
     * @return Tags
     */
    public static function create(Tag ...$tags): Tags
    {
        return new self(...$tags);
    }
    
    
    /**
     * @return array Returns array of objects, that matches the Tag schema from "configuration.schema.json".
     */
    public function jsonSerialize(): array
    {
        return $this->tags;
    }
    
    
    /**
     * @return ArrayIterator|Tag[]
     */
    public function getIterator()
    {
        return new ArrayIterator($this->tags);
    }
}