<?php
/* --------------------------------------------------------------
   ParcelServiceSorting.php 2020-08-28
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2020 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\ParcelService\App\Data\Filter;

use Doctrine\DBAL\Query\QueryBuilder;
use Gambio\Admin\Modules\ParcelService\Model\ValueObjects\ParcelServiceSorting as ParcelServiceSortingInterface;

/**
 * Class ParcelServiceSorting
 *
 * @package Gambio\Admin\Modules\ParcelService\SqlCriteria
 */
class ParcelServiceSorting implements ParcelServiceSortingInterface
{
    /**
     * @var string
     */
    private $sorting;
    
    /**
     * @var string[]
     */
    private static $attributeColumnMapping = [
        'id'                   => 'parcel_services.parcel_service_id',
        'name'                 => 'parcel_services.name',
        'isDefault'            => 'parcel_services.default',
        'descriptions.url'     => 'parcel_services_description.url',
        'descriptions.comment' => 'parcel_services_description.comment',
    ];
    
    
    /**
     * ParcelServiceSorting constructor.
     *
     * @param string $sorting
     */
    private function __construct(string $sorting)
    {
        $this->sorting = $sorting;
    }
    
    
    /**
     * @param string $sorting
     *
     * @return ParcelServiceSorting
     */
    public static function create(string $sorting = ''): ParcelServiceSorting
    {
        return new self($sorting);
    }
    
    
    /**
     * @param QueryBuilder $query
     */
    public function applyToQuery(QueryBuilder $query): void
    {
        foreach (explode(',', $this->sorting) as $attribute) {
            if (trim($attribute, '-+') === '') {
                continue;
            }
            
            $order  = (strpos($attribute, '-') === 0) ? 'desc' : 'asc';
            $column = self::$attributeColumnMapping[trim($attribute, '-+')];
            
            $query->addOrderBy($column, $order);
        }
    }
}