<?php
/* --------------------------------------------------------------
   ParcelServiceService.php 2020-08-28
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2020 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\ParcelService\App;

use Gambio\Admin\Modules\ParcelService\App\Data\Filter\ParcelServiceFilterFactory;
use Gambio\Admin\Modules\ParcelService\Model\Collections\ParcelServices;
use Gambio\Admin\Modules\ParcelService\Services\ParcelServiceFilterService as ParcelServiceFilterServiceInterface;
use Gambio\Admin\Modules\ParcelService\Services\ParcelServiceRepository;

/**
 * Class ParcelServiceService
 *
 * @package Gambio\Admin\Modules\ParcelService
 */
class ParcelServiceFilterService implements ParcelServiceFilterServiceInterface
{
    /**
     * @var ParcelServiceRepository
     */
    private $repository;
    
    /**
     * @var ParcelServiceFilterFactory
     */
    private $factory;
    
    
    /**
     * ParcelServiceFilterService constructor.
     *
     * @param ParcelServiceRepository    $repository
     * @param ParcelServiceFilterFactory $factory
     */
    public function __construct(ParcelServiceRepository $repository, ParcelServiceFilterFactory $factory)
    {
        $this->repository = $repository;
        $this->factory    = $factory;
    }
    
    
    /**
     * @inheritDoc
     */
    public function filterParcelServices(
        array $filters,
        string $sorting,
        int $limit = 25,
        int $offset = 0
    ): ParcelServices {
        $filters = array_map([$this, 'mapFilter'], $filters);
        
        return $this->repository->filterParcelServices($this->factory->createFilters($filters),
                                                       $this->factory->createSorting($sorting),
                                                       $this->factory->createPagination($limit, $offset));
    }
    
    
    /**
     * @inheritDoc
     */
    public function getParcelServicesTotalCount(array $filters): int
    {
        $filters = array_map([$this, 'mapFilter'], $filters);
        
        return $this->repository->getParcelServicesTotalCount($this->factory->createFilters($filters));
    }
    
    
    /**
     * @param string $filter
     *
     * @return array
     */
    private function mapFilter(string $filter): array
    {
        $value     = $filter;
        $operation = (strpos($value, '*') !== false) ? 'like' : 'eq';
        if (strpos($filter, '|') !== false) {
            $value     = substr($filter, strpos($filter, '|') + 1);
            $operation = substr($filter, 0, strpos($filter, '|'));
        }
        
        return [
            'value'     => $value,
            'operation' => $operation,
        ];
    }
}