<?php
/* --------------------------------------------------------------
   ParcelServiceWriteService.php 2020-08-28
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2020 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\ParcelService\Services;

use Gambio\Admin\Modules\ParcelService\Model\Collections\ParcelServiceDescriptions;
use Gambio\Admin\Modules\ParcelService\Model\Collections\ParcelServiceIds;
use Gambio\Admin\Modules\ParcelService\Model\Exceptions\CreationOfParcelServicesFailed;
use Gambio\Admin\Modules\ParcelService\Model\Exceptions\DeletionOfParcelServicesFailed;
use Gambio\Admin\Modules\ParcelService\Model\Exceptions\StorageOfParcelServicesFailed;
use Gambio\Admin\Modules\ParcelService\Model\ParcelService;
use Gambio\Admin\Modules\ParcelService\Model\ValueObjects\ParcelServiceId;

/**
 * Interface ParcelServiceWriteService
 *
 * @package Gambio\Admin\Modules\ParcelService\Services
 */
interface ParcelServiceWriteService
{
    /**
     * @param string                    $name
     * @param ParcelServiceDescriptions $descriptions
     * @param bool                      $isDefault
     *
     * @return ParcelServiceId
     *
     * @throws CreationOfParcelServicesFailed
     */
    public function createParcelService(
        string $name,
        ParcelServiceDescriptions $descriptions,
        bool $isDefault = false
    ): ParcelServiceId;
    
    
    /**
     * @param string[]                    $names
     * @param ParcelServiceDescriptions[] $descriptions
     * @param bool[]                      $isDefaultFlags
     *
     * @return ParcelServiceIds
     *
     * @throws CreationOfParcelServicesFailed
     */
    public function createMultipleParcelServices(
        array $names,
        array $descriptions,
        array $isDefaultFlags = []
    ): ParcelServiceIds;
    
    
    /**
     * @param ParcelService ...$parcelServices
     *
     * @throws StorageOfParcelServicesFailed
     */
    public function storeParcelServices(ParcelService ...$parcelServices): void;
    
    
    /**
     * @param int ...$ids
     *
     * @throws DeletionOfParcelServicesFailed
     */
    public function deleteParcelServices(int ...$ids): void;
}