<?php
/*------------------------------------------------------------------------------
 CategoryCollection.php 2021-06-07
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2021 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 -----------------------------------------------------------------------------*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\Statistics\Collections;

use Gambio\Admin\Modules\Statistics\ValueObjects\Category;

/**
 * Class CategoryCollection
 * @package Gambio\Admin\Modules\Statistics\Collections
 */
class CategoryCollection extends AbstractCollection implements \JsonSerializable
{
    /**
     * @return Category
     */
    public function current(): Category
    {
        return $this->currentValue();
    }
    
    
    /**
     * @inheritDoc
     */
    protected function isValid($value): bool
    {
        return $value instanceof Category;
    }
    
    
    /**
     * @return array
     */
    public function jsonSerialize()
    {
        $result = [];
        /** @var Category $category */
        foreach ($this->values as $category) {
            $result[$category->name()->value()] = [
                'title'                 => $category->title()->value(),
                'unit'                  => $category->unit()->value(),
                'style'                 => $category->style()->value(),
                'minimumFractionDigits' => $category->minimumFractionDigits()->value(),
            ];
        }
    
        return $result;
    }
}