<?php
/*--------------------------------------------------------------
  DataProviderResult.php 2021-06-07
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2021 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  -------------------------------------------------------------*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\Statistics\Entities;

use Gambio\Admin\Modules\Statistics\Collections\StatisticValueCollection;
use Gambio\Admin\Modules\Statistics\ValueObjects\Name;
use Gambio\Admin\Modules\Statistics\ValueObjects\Title;
use Gambio\Admin\Modules\Statistics\ValueObjects\Unit;
use Gambio\Admin\Modules\Statistics\ValueObjects\Style;
use Gambio\Admin\Modules\Statistics\ValueObjects\MinimumFractionDigits;
use JsonSerializable;

/**
 * Class DataProviderResult
 *
 * @package Gambio\Admin\Modules\Statistics\Entities
 */
class DataProviderResult implements JsonSerializable
{
    /**
     * @var Name
     */
    protected $name;
    
    /**
     * @var Title
     */
    protected $title;
    
    /**
     * @var Unit
     */
    protected $unit;
    
    /**
     * @var Style
     */
    protected $style;
    
    /**
     * @var MinimumFractionDigits
     */
    protected $minimumFractionDigits;
    
    /**
     * @var StatisticValueCollection
     */
    protected $statisticValues;
    
    
    /**
     * DataProviderResult constructor.
     *
     * @param Name                     $name
     * @param Title                    $title
     * @param Unit                     $unit
     * @param Style                    $style
     * @param MinimumFractionDigits    $minimumFractionDigits
     * @param StatisticValueCollection $statisticValues
     */
    public function __construct(
        Name $name,
        Title $title,
        Unit $unit,
        Style $style,
        MinimumFractionDigits $minimumFractionDigits,
        StatisticValueCollection $statisticValues
    ) {
        $this->name            = $name;
        $this->title           = $title;
        $this->unit                  = $unit;
        $this->style                 = $style;
        $this->minimumFractionDigits = $minimumFractionDigits;
        $this->statisticValues = $statisticValues;
    }
    
    
    /**
     * @return Name
     */
    public function name(): Name
    {
        return $this->name;
    }
    
    
    /**
     * @return Title
     */
    public function title(): Title
    {
        return $this->title;
    }
    
    
    /**
     * @return Unit
     */
    public function unit(): Unit
    {
        return $this->unit;
    }
    
    
    /**
     * @return Style
     */
    public function style(): Style
    {
        return $this->style;
    }
    
    
    /**
     * @return MinimumFractionDigits
     */
    public function minimumFractionDigits(): MinimumFractionDigits
    {
        return $this->minimumFractionDigits;
    }
    
    
    /**
     * @return StatisticValueCollection
     */
    public function statisticValueCollection(): StatisticValueCollection
    {
        return $this->statisticValues;
    }
    
    
    /**
     * @inheritDoc
     */
    public function jsonSerialize(): object
    {
        return (object)[
            'name'                  => $this->name(),
            'title'                 => $this->title(),
            'unit'                  => $this->unit(),
            'style'                 => $this->style(),
            'minimumFractionDigits' => $this->minimumFractionDigits(),
            'values'                => $this->statisticValueCollection(),
        ];
    }
}