<?php
/*------------------------------------------------------------------------------
  AbstractSummarizableTimespan.php 2021-05-28
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2021 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  -----------------------------------------------------------------------------*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\Statistics\Entities;

use DateTimeInterface;
use Exception;
use Gambio\Admin\Modules\Statistics\Factories\Exceptions\InvalidDateTimespanException;
use Gambio\Admin\Modules\Statistics\Summarizer\StatisticSummarizer;
use Gambio\Admin\Modules\Statistics\ValueObjects\SummarizedData;

class SummarizableTimespan extends Timespan
{
    /**
     * @var StatisticSummarizer
     */
    private $summarizer;
    
    
    /**
     * SummarizableTimespan constructor.
     *
     * @param DateTimeInterface      $startDate
     * @param DateTimeInterface      $endDate
     * @param StatisticSummarizer    $summarizer
     * @param string                 $name
     * @param DateTimeInterface|null $totalsStartDate
     * @param DateTimeInterface|null $totalsEndDate
     *
     * @throws InvalidDateTimespanException
     */
    public function __construct(
        DateTimeInterface $startDate,
        DateTimeInterface $endDate,
        StatisticSummarizer $summarizer,
        string $name,
        ?DateTimeInterface $totalsStartDate = null,
        ?DateTimeInterface $totalsEndDate = null
    ) {
        parent::__construct($startDate, $endDate, $name, $totalsStartDate, $totalsEndDate);
        $this->summarizer = $summarizer;
    }
    
    
    /**
     * @param DataProviderResult[] $values
     *
     * @return SummarizedData
     * @throws Exception
     */
    public function summarize(DataProviderResult ...$values): SummarizedData
    {
        return $this->summarizer->summarize($this, ...$values);
    }
    
}