<?php
/*--------------------------------------------------------------
   ConversionDataProviderResultFactory.php 2021-06-07
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2021 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
 -------------------------------------------------------------*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\Statistics\Repositories\Conversion\Factories;

use Gambio\Admin\Modules\Statistics\Collections\StatisticValueCollection;
use Gambio\Admin\Modules\Statistics\Repositories\Conversion\Entities\ConversionDataProviderResult;
use Gambio\Admin\Modules\Statistics\ValueObjects\Title;
use Gambio\Admin\Modules\Statistics\ValueObjects\Unit;
use Gambio\Admin\Modules\Statistics\ValueObjects\Style;
use Gambio\Admin\Modules\Statistics\ValueObjects\MinimumFractionDigits;
use Gambio\Core\Language\TextManager;

/**
 * Class ConversionDataProviderResultFactory
 *
 * @package Gambio\Admin\Modules\Statistics\Repositories\Conversion\Factories
 */
class ConversionDataProviderResultFactory
{
    private const CONVERSION_TITLE_PHRASE = 'conversion_title';
    private const LANGUAGE_SECTION        = 'statistics_service';
    
    /**
     * @var TextManager
     */
    private $textManager;
    
    
    /**
     * ConversionDataProviderResultFactory constructor.
     *
     * @param TextManager $textManager
     */
    public function __construct(TextManager $textManager)
    {
        $this->textManager = $textManager;
    }
    
    
    /**
     * @param StatisticValueCollection $collection
     *
     * @return ConversionDataProviderResult
     */
    public function create(StatisticValueCollection $collection): ConversionDataProviderResult
    {
        return new ConversionDataProviderResult($this->createTitle(),
                                                new Unit('%'),
                                                new Style('percent'),
                                                new MinimumFractionDigits(2),
                                                $collection);
    }
    
    
    /**
     * @return Title
     */
    private function createTitle(): Title
    {
        return new Title($this->textManager->getPhraseText(static::CONVERSION_TITLE_PHRASE, static::LANGUAGE_SECTION));
    }
}