<?php
/* --------------------------------------------------------------
  OrdersDataProviderResultFactory.php 2021-06-07
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2021 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  --------------------------------------------------------------*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\Statistics\Repositories\Orders\Factories;

use Gambio\Admin\Modules\Statistics\Collections\StatisticValueCollection;
use Gambio\Admin\Modules\Statistics\Repositories\Orders\Entities\OrdersDataProviderResult;
use Gambio\Admin\Modules\Statistics\ValueObjects\Title;
use Gambio\Admin\Modules\Statistics\ValueObjects\Unit;
use Gambio\Admin\Modules\Statistics\ValueObjects\Style;
use Gambio\Admin\Modules\Statistics\ValueObjects\MinimumFractionDigits;
use Gambio\Core\Language\TextManager;

/**
 * Class OrdersDataProviderResultFactory
 *
 * @package Gambio\Admin\Modules\Statistics\Repositories\Orders\Factories
 */
class OrdersDataProviderResultFactory
{
    private const ORDERS_TITLE_PHRASE = 'orders_title';
    private const LANGUAGE_SECTION    = 'statistics_service';
    
    /**
     * @var TextManager
     */
    private $textManager;
    
    
    /**
     * OrdersDataProviderResultFactory constructor.
     *
     * @param TextManager $languageTextManager
     */
    public function __construct(TextManager $languageTextManager)
    {
        $this->textManager = $languageTextManager;
    }
    
    
    /**
     * @param StatisticValueCollection $collection
     *
     * @return OrdersDataProviderResult
     */
    public function create(StatisticValueCollection $collection): OrdersDataProviderResult
    {
        return new OrdersDataProviderResult($this->getTitle(),
                                            new Unit(''),
                                            new Style(''),
                                            new MinimumFractionDigits(0),
                                            $collection);
    }
    
    
    /**
     * @return Title
     */
    private function getTitle(): Title
    {
        return new Title($this->textManager->getPhraseText(static::ORDERS_TITLE_PHRASE, static::LANGUAGE_SECTION));
    }
}