<?php
/*--------------------------------------------------------------
   OrdersDataProvider.php 2020-08-13
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2020 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
 -------------------------------------------------------------*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\Statistics\Repositories\Orders;

use Gambio\Admin\Modules\Statistics\Entities\DataProviderResult;
use Gambio\Admin\Modules\Statistics\Entities\Timespan;
use Gambio\Admin\Modules\Statistics\Repositories\Orders\Factories\OrdersDataProviderResultFactory;
use Gambio\Admin\Modules\Statistics\Repositories\Orders\Readers\OrdersReader;
use Gambio\Admin\Modules\Statistics\Repositories\StatisticsDataProvider;

/**
 * Class OrdersDataProvider
 * @package Gambio\Admin\Modules\Statistics\Repositories
 */
class OrdersDataProvider implements StatisticsDataProvider
{
    /**
     * @var OrdersReader
     */
    private $reader;
    /**
     * @var OrdersDataProviderResultFactory
     */
    private $factory;
    
    
    /**
     * OrdersDataProvider constructor.
     *
     * @param OrdersReader                    $reader
     * @param OrdersDataProviderResultFactory $factory
     */
    public function __construct(OrdersReader $reader, OrdersDataProviderResultFactory $factory)
    {
        $this->reader  = $reader;
        $this->factory = $factory;
    }
    
    
    /**
     * @inheritDoc
     */
    public function fromTimespan(Timespan $timespan): DataProviderResult
    {
        return $this->factory->create($this->reader->getByTimespan($timespan));
    }
}