<?php
/*--------------------------------------------------------------
  SalesDataProviderResultFactory.php 2021-06-08
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2021 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  -------------------------------------------------------------*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\Statistics\Repositories\Sales\Factories;

use Gambio\Admin\Modules\Statistics\Collections\StatisticValueCollection;
use Gambio\Admin\Modules\Statistics\Repositories\Sales\Entities\SalesDataProviderResult;
use Gambio\Admin\Modules\Statistics\ValueObjects\Title;
use Gambio\Admin\Modules\Statistics\ValueObjects\Unit;
use Gambio\Admin\Modules\Statistics\ValueObjects\Style;
use Gambio\Admin\Modules\Statistics\ValueObjects\MinimumFractionDigits;
use Gambio\Core\Configuration\Services\ConfigurationService;
use Gambio\Core\Language\TextManager;

/**
 * Class SalesDataProviderResultFactory
 *
 * @package Gambio\Admin\Modules\Statistics\Repositories\Sales\Factories
 */
class SalesDataProviderResultFactory
{
    private const SALES_TITLE_PHRASE = 'sales_title';
    private const LANGUAGE_SECTION   = 'statistics_service';
    
    /**
     * @var TextManager
     */
    private $languageTextManager;
    
    /**
     * @var ConfigurationService
     */
    private $configurationService;
    
    
    /**
     * SalesDataProviderResultFactory constructor.
     *
     * @param TextManager          $languageTextManager
     * @param ConfigurationService $configurationService
     */
    public function __construct(TextManager $languageTextManager, ConfigurationService $configurationService)
    {
        $this->languageTextManager  = $languageTextManager;
        $this->configurationService = $configurationService;
    }
    
    
    /**
     * @param StatisticValueCollection $collection
     *
     * @return SalesDataProviderResult
     */
    public function create(StatisticValueCollection $collection): SalesDataProviderResult
    {
        $unit = $this->configurationService->find('configuration/DEFAULT_CURRENCY');
        
        return new SalesDataProviderResult($this->createTitle(),
                                           new Unit($unit ? $unit->value() : 'EUR'),
                                           new Style('currency'),
                                           new MinimumFractionDigits(0),
                                           $collection);
    }
    
    
    /**
     * @return Title
     */
    private function createTitle(): Title
    {
        return new Title($this->languageTextManager->getPhraseText(static::SALES_TITLE_PHRASE,
                                                                   static::LANGUAGE_SECTION));
    }
}