<?php
/*--------------------------------------------------------------
   SalesDataProvider.php 2020-08-13
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2020 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
 -------------------------------------------------------------*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\Statistics\Repositories\Sales;

use Gambio\Admin\Modules\Statistics\Entities\DataProviderResult;
use Gambio\Admin\Modules\Statistics\Entities\Timespan;
use Gambio\Admin\Modules\Statistics\Repositories\Sales\Factories\SalesDataProviderResultFactory;
use Gambio\Admin\Modules\Statistics\Repositories\Sales\Reader\SalesReader;
use Gambio\Admin\Modules\Statistics\Repositories\StatisticsDataProvider;

/**
 * Class SalesDataProvider
 * @package Gambio\Admin\Modules\Statistics\Repositories\Sales
 */
class SalesDataProvider implements StatisticsDataProvider
{
    /**
     * @var SalesReader
     */
    private $reader;
    
    /**
     * @var SalesDataProviderResultFactory
     */
    private $factory;
    
    
    /**
     * SalesDataProvider constructor.
     *
     * @param SalesReader                    $reader
     * @param SalesDataProviderResultFactory $factory
     */
    public function __construct(SalesReader $reader, SalesDataProviderResultFactory $factory)
    {
        $this->reader  = $reader;
        $this->factory = $factory;
    }
    
    
    /**
     * @inheritDoc
     */
    public function fromTimespan(Timespan $timespan): DataProviderResult
    {
        return $this->factory->create($this->reader->fromTimespan($timespan));
    }
}