<?php
/* --------------------------------------------------------------
  VisitorsDataProviderResultFactory.php 2021-06-07
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2021 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Modules\Statistics\Repositories\Visitors\Factories;

use Gambio\Admin\Modules\Statistics\Collections\StatisticValueCollection;
use Gambio\Admin\Modules\Statistics\Repositories\Visitors\Entities\VisitorsDataProviderResult;
use Gambio\Admin\Modules\Statistics\ValueObjects\Title;
use Gambio\Admin\Modules\Statistics\ValueObjects\Unit;
use Gambio\Admin\Modules\Statistics\ValueObjects\Style;
use Gambio\Admin\Modules\Statistics\ValueObjects\MinimumFractionDigits;
use Gambio\Core\Language\TextManager;

/**
 * Class VisitorsDataProviderResultFactory
 *
 * @package Gambio\Admin\Modules\Statistics\Repositories\Visitors\ValueObjects
 */
class VisitorsDataProviderResultFactory
{
    private const VISITORS_TITLE_PHRASE = 'visitors_title';
    private const LANGUAGE_SECTION      = 'statistics_service';
    
    /**
     * @var TextManager
     */
    private $languageTextManager;
    
    
    /**
     * VisitorsDataProviderResultFactory constructor.
     *
     * @param TextManager $textManager
     */
    public function __construct(TextManager $textManager)
    {
        $this->languageTextManager = $textManager;
    }
    
    
    /**
     * @param StatisticValueCollection $collection
     *
     * @return VisitorsDataProviderResult
     */
    public function create(StatisticValueCollection $collection): VisitorsDataProviderResult
    {
        return new VisitorsDataProviderResult($this->createTitle(),
                                              new Unit(''),
                                              new Style(''),
                                              new MinimumFractionDigits(0),
                                              $collection);
    }
    
    
    /**
     * @return Title
     */
    private function createTitle(): Title
    {
        return new Title($this->languageTextManager->getPhraseText(static::VISITORS_TITLE_PHRASE,
                                                                   static::LANGUAGE_SECTION));
    }
}