<?php
/* --------------------------------------------------------------
 BasicVisitorReader.php 2021-05-28
 Gambio GmbH
 http://www.gambio.de

 Copyright (c) 2021 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Modules\Statistics\Repositories\Visitors\Readers;

use Doctrine\DBAL\Connection;
use Gambio\Admin\Modules\Statistics\Collections\StatisticValueCollection;
use Gambio\Admin\Modules\Statistics\Entities\StatisticValue;
use Gambio\Admin\Modules\Statistics\Entities\Timespan;
use Gambio\Admin\Modules\Statistics\ValueObjects\DateString;

/**
 * Class BasicVisitorReader
 * @package Gambio\Admin\Modules\Statistics\Repositories\Visitors\Reader
 */
class BasicVisitorReader implements VisitorsReader
{
    
    /**
     * @var Connection
     */
    private $connection;
    
    
    /**
     * BasicVisitorReader constructor.
     *
     * @param Connection $connection
     */
    public function __construct(Connection $connection)
    {
        $this->connection = $connection;
    }
    
    
    /**
     * @inheritDoc
     */
    public function fromTimespan(Timespan $timespan): StatisticValueCollection
    {
        $queryBuilder = $this->connection->createQueryBuilder();
        $collection = new StatisticValueCollection;

        $queryResult = $queryBuilder->select('sum(gm_counter_visits_total) as amount, DATE(gm_counter_date) as date')
            ->from('gm_counter_visits')
            ->where("gm_counter_date BETWEEN '" . $timespan->startDate()->format('Y-m-d H:i:s') . "' AND '" . $timespan->endDate()->format('Y-m-d H:i:s')."'")
            ->groupBy('DATE(gm_counter_date)')
            ->orderBy('DATE(gm_counter_date)')
            ->execute()
            ->fetchAll();
        
        foreach ($queryResult as $item) {
            $collection[] = new StatisticValue(new DateString($item['date']),(int)$item['amount']);
        }

        return $collection;
    }
}