<?php
/*------------------------------------------------------------------------------
 Category.php 2021-06-07
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2021 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 -----------------------------------------------------------------------------*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\Statistics\ValueObjects;

/**
 * Class Category
 * @package Gambio\Admin\Modules\Statistics\ValueObjects
 */
class Category
{
    /**
     * @var Name
     */
    private $name;
    
    /**
     * @var Title
     */
    private $title;
    
    /**
     * @var Unit
     */
    private $unit;
    
    /**
     * @var Style
     */
    private $style;
    
    /**
     * @var MinimumFractionDigits
     */
    private $minimumFractionDigits;
    
    
    /**
     * Category constructor.
     *
     * @param Name                  $name
     * @param Title                 $title
     * @param Unit                  $unit
     * @param Style                 $style
     * @param MinimumFractionDigits $minimumFractionDigits
     */
    public function __construct(Name $name, Title $title, Unit $unit, Style $style, MinimumFractionDigits $minimumFractionDigits)
    {
        $this->name                  = $name;
        $this->title                 = $title;
        $this->unit                  = $unit;
        $this->style                 = $style;
        $this->minimumFractionDigits = $minimumFractionDigits;
    }
    
    
    /**
     * @return Name
     */
    public function name(): Name
    {
        return $this->name;
    }
    
    
    /**
     * @return Title
     */
    public function title(): Title
    {
        return $this->title;
    }
    
    
    /**
     * @return Unit
     */
    public function unit(): Unit
    {
        return $this->unit;
    }
    
    
    /**
     * @return Style
     */
    public function style(): Style
    {
        return $this->style;
    }
    
    
    /**
     * @return MinimumFractionDigits
     */
    public function minimumFractionDigits(): MinimumFractionDigits
    {
        return $this->minimumFractionDigits;
    }
}