<?php
/*------------------------------------------------------------------------------
 StatisticsResult.php 2020-08-17
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 -----------------------------------------------------------------------------*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\Statistics\ValueObjects;

use Gambio\Admin\Modules\Statistics\Collections\CategoryCollection;
use Gambio\Admin\Modules\Statistics\Collections\SummarizedDataCollection;
use Gambio\Admin\Modules\Statistics\Entities\DataProviderResult;
use JsonSerializable;

/**
 * Class StatisticsResult
 * @package Gambio\Admin\Modules\Statistics\ValueObjects
 */
class StatisticsResult implements JsonSerializable
{
    /**
     * @var SummarizedDataCollection
     */
    private $statistics;
    
    /**
     * @var CategoryCollection
     */
    private $categories;
    
    
    /**
     * StatisticsResult constructor.
     *
     * @param SummarizedDataCollection $statistics
     * @param CategoryCollection       $categories
     */
    public function __construct(SummarizedDataCollection $statistics, CategoryCollection $categories)
    {
        $this->statistics = $statistics;
        $this->categories = $categories;
    }
    
    
    /**
     * @return SummarizedDataCollection
     */
    public function statistics(): SummarizedDataCollection
    {
        return $this->statistics;
    }
    
    
    /**
     * @return CategoryCollection
     */
    public function categories(): CategoryCollection
    {
        return $this->categories;
    }
    
    
    /**
     * @return array
     */
    public function jsonSerialize()
    {
        return [
            'categories' => $this->categories,
            'statistics' => $this->statistics
        ];
    }
}