<?php
/* --------------------------------------------------------------
  UserPreferredCategory.php 2021-06-09
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2021 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Modules\Statistics\ValueObjects;

use Gambio\Admin\Modules\Statistics\Exceptions\NoValidUserPreferredCategoryException;

/**
 * Class UserPreferredCategory
 * @package Gambio\Admin\Modules\Statistics\ValueObjects
 */
class UserPreferredCategory implements \JsonSerializable
{
    /**
     * @var string
     */
    private $category;
    
    /**
     * @var string[]
     */
    private $categories = [
        'sales',
        'orders',
        'conversions',
        'visitors',
    ];
    
    
    /**
     * UserPreferredCategory constructor.
     *
     * @param string $category
     *
     * @throws NoValidUserPreferredCategoryException
     */
    public function __construct(string $category)
    {
        if (!in_array($category, $this->categories)) {
            throw NoValidUserPreferredCategoryException::create($category);
        }
        
        $this->category = $category;
    }
    
    
    /**
     * @return string
     */
    public function value(): string
    {
        return $this->category;
    }
    
    
    /**
     * @inheritDoc
     */
    public function jsonSerialize()
    {
        return $this->category;
    }
}