<?php
/* --------------------------------------------------------------
  UserPreferredPeriod.php 2021-06-03
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2021 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Admin\Modules\Statistics\ValueObjects;

use Gambio\Admin\Modules\Statistics\Exceptions\NoValidUserPreferredPeriodException;

/**
 * Class UserPreferredPeriod
 * @package Gambio\Admin\Modules\Statistics\ValueObjects
 */
class UserPreferredPeriod implements \JsonSerializable
{
    /**
     * @var string
     */
    private $period;
    
    /**
     * @var string[]
     */
    private $periods = [
        'today',
        'thisweek',
        'last7days',
        'thismonth',
        'last28days',
        'thisyear',
        'last12months'
    ];
    
    
    /**
     * UserPreferredPeriod constructor.
     *
     * @param string $period
     *
     * @throws NoValidUserPreferredPeriodException
     */
    public function __construct(string $period)
    {
        if (!in_array($period, $this->periods)) {
            throw NoValidUserPreferredPeriodException::create($period);
        }
        
        $this->period = $period;
    }
    
    
    /**
     * @return string
     */
    public function value(): string
    {
        return $this->period;
    }
    
    
    /**
     * @inheritDoc
     */
    public function jsonSerialize()
    {
        return $this->period;
    }
}