<?php
/* --------------------------------------------------------------
   TrackingCodeSorting.php 2020-09-01
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2020 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\TrackingCode\App\Data\Filter;

use Doctrine\DBAL\Query\QueryBuilder;
use Gambio\Admin\Modules\TrackingCode\Model\ValueObjects\TrackingCodeSorting as TrackingCodeSortingInterface;

/**
 * Class TrackingCodeSorting
 *
 * @package Gambio\Admin\Modules\TrackingCode\SqlCriteria
 */
class TrackingCodeSorting implements TrackingCodeSortingInterface
{
    /**
     * @var string
     */
    private $sorting;
    
    /**
     * @var string[]
     */
    private static $attributeColumnMapping = [
        'id'                         => 'orders_parcel_tracking_codes.orders_parcel_tracking_code_id',
        'orderId'                    => 'orders_parcel_tracking_codes.order_id',
        'code'                       => 'orders_parcel_tracking_codes.tracking_code',
        'parcelService.id'           => 'orders_parcel_tracking_codes.parcel_service_id',
        'parcelService.languageId'   => 'orders_parcel_tracking_codes.language_id',
        'parcelService.languageCode' => 'languages.code',
        'parcelService.name'         => 'orders_parcel_tracking_codes.parcel_service_name',
        'parcelService.url'          => 'orders_parcel_tracking_codes.url',
        'parcelService.comment'      => 'orders_parcel_tracking_codes.comment',
        'createdOn'                  => 'orders_parcel_tracking_codes.creation_date',
    ];
    
    
    /**
     * TrackingCodeSorting constructor.
     *
     * @param string $sorting
     */
    private function __construct(string $sorting)
    {
        $this->sorting = $sorting;
    }
    
    
    /**
     * @param string $sorting
     *
     * @return TrackingCodeSorting
     */
    public static function create(string $sorting = ''): TrackingCodeSorting
    {
        return new self($sorting);
    }
    
    
    /**
     * @param QueryBuilder $query
     */
    public function applyToQuery(QueryBuilder $query): void
    {
        foreach (explode(',', $this->sorting) as $attribute) {
            if (trim($attribute, '-+') === '') {
                continue;
            }
            
            $order  = (strpos($attribute, '-') === 0) ? 'desc' : 'asc';
            $column = self::$attributeColumnMapping[trim($attribute, '-+')];
            
            $query->addOrderBy($column, $order);
        }
    }
}