<?php
/* --------------------------------------------------------------
   TrackingCodeService.php 2020-09-01
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2020 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\TrackingCode\App;

use Gambio\Admin\Modules\TrackingCode\Model\Collections\TrackingCodeIds;
use Gambio\Admin\Modules\TrackingCode\Model\ValueObjects\ParcelServiceDetails;
use Gambio\Admin\Modules\TrackingCode\Model\ValueObjects\TrackingCodeId;
use Gambio\Admin\Modules\TrackingCode\Services\TrackingCodeFactory;
use Gambio\Admin\Modules\TrackingCode\Services\TrackingCodeRepository;
use Gambio\Admin\Modules\TrackingCode\Services\TrackingCodeWriteService as TrackingCodeWriteServiceInterface;

/**
 * Class TrackingCodeService
 *
 * @package Gambio\Admin\Modules\TrackingCode
 */
class TrackingCodeWriteService implements TrackingCodeWriteServiceInterface
{
    /**
     * @var TrackingCodeRepository
     */
    private $repository;
    
    /**
     * @var TrackingCodeFactory
     */
    private $factory;
    
    
    /**
     * TrackingCodeWriteService constructor.
     *
     * @param TrackingCodeRepository $repository
     * @param TrackingCodeFactory    $factory
     */
    public function __construct(TrackingCodeRepository $repository, TrackingCodeFactory $factory)
    {
        $this->repository = $repository;
        $this->factory    = $factory;
    }
    
    
    /**
     * @inheritDoc
     */
    public function createTrackingCode(
        int $orderId,
        string $code,
        ParcelServiceDetails $parcelServiceDetails
    ): TrackingCodeId {
        return $this->repository->createTrackingCode($this->factory->createOrderId($orderId),
                                                     $code,
                                                     $parcelServiceDetails);
    }
    
    
    /**
     * @inheritDoc
     */
    public function createMultipleTrackingCodes(
        array $orderIds,
        array $codes,
        array $parcelServiceDetails
    ): TrackingCodeIds {
        $orderIds = array_map([$this->factory, 'createOrderId'], $orderIds);
        
        return $this->repository->createMultipleTrackingCodes($orderIds,
                                                              $codes,
                                                              $parcelServiceDetails);
    }
    
    
    /**
     * @inheritDoc
     */
    public function deleteTrackingCodes(int ...$ids): void
    {
        $ids = array_map([$this->factory, 'createTrackingCodeId'], $ids);
        
        $this->repository->deleteTrackingCodes(... $ids);
    }
}