<?php
/* --------------------------------------------------------------
   TrackingCodeRepository.php 2020-09-01
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2020 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\TrackingCode\Services;

use Gambio\Admin\Modules\TrackingCode\Model\Collections\TrackingCodeIds;
use Gambio\Admin\Modules\TrackingCode\Model\Collections\TrackingCodes;
use Gambio\Admin\Modules\TrackingCode\Model\Exceptions\CreationOfTrackingCodesFailed;
use Gambio\Admin\Modules\TrackingCode\Model\Exceptions\DeletionOfTrackingCodesFailed;
use Gambio\Admin\Modules\TrackingCode\Model\Exceptions\TrackingCodeNotFoundException;
use Gambio\Admin\Modules\TrackingCode\Model\TrackingCode;
use Gambio\Admin\Modules\TrackingCode\Model\ValueObjects\OrderId;
use Gambio\Admin\Modules\TrackingCode\Model\ValueObjects\ParcelServiceDetails;
use Gambio\Admin\Modules\TrackingCode\Model\ValueObjects\TrackingCodeFilters;
use Gambio\Admin\Modules\TrackingCode\Model\ValueObjects\TrackingCodeId;
use Gambio\Admin\Modules\TrackingCode\Model\ValueObjects\TrackingCodePagination;
use Gambio\Admin\Modules\TrackingCode\Model\ValueObjects\TrackingCodeSorting;

/**
 * Interface TrackingCodeRepository
 *
 * @package Gambio\Admin\Modules\TrackingCode\Services
 */
interface TrackingCodeRepository
{
    /**
     * @param TrackingCodeFilters    $filters
     * @param TrackingCodeSorting    $sorting
     * @param TrackingCodePagination $pagination
     *
     * @return TrackingCodes
     */
    public function filterTrackingCodes(
        TrackingCodeFilters $filters,
        TrackingCodeSorting $sorting,
        TrackingCodePagination $pagination
    ): TrackingCodes;
    
    
    /**
     * @param TrackingCodeFilters $criteria
     *
     * @return int
     */
    public function getTrackingCodesTotalCount(TrackingCodeFilters $criteria): int;
    
    
    /**
     * @return TrackingCodes
     */
    public function getAllTrackingCodes(): TrackingCodes;
    
    
    /**
     * @param TrackingCodeId $id
     *
     * @return TrackingCode
     *
     * @throws TrackingCodeNotFoundException
     */
    public function getTrackingCodeById(TrackingCodeId $id): TrackingCode;
    
    
    /**
     * @param OrderId              $orderId
     * @param string               $code
     * @param ParcelServiceDetails $parcelServiceDetails
     *
     * @return TrackingCodeId
     *
     * @throws CreationOfTrackingCodesFailed
     */
    public function createTrackingCode(
        OrderId $orderId,
        string $code,
        ParcelServiceDetails $parcelServiceDetails
    ): TrackingCodeId;
    
    
    /**
     * @param OrderId[]              $orderIds
     * @param string[]               $codes
     * @param ParcelServiceDetails[] $parcelServiceDetails
     *
     * @return TrackingCodeIds
     *
     * @throws CreationOfTrackingCodesFailed
     */
    public function createMultipleTrackingCodes(
        array $orderIds,
        array $codes,
        array $parcelServiceDetails
    ): TrackingCodeIds;
    
    
    /**
     * @param TrackingCodeId ...$ids
     *
     * @throws DeletionOfTrackingCodesFailed
     */
    public function deleteTrackingCodes(TrackingCodeId ...$ids): void;
    
    
    /**
     * @param OrderId $orderId
     *
     * @return TrackingCodes
     */
    public function getTrackingCodesByOrderId(OrderId $orderId): TrackingCodes;
}