<?php
/* --------------------------------------------------------------
   TrackingCodeWriteService.php 2020-09-01
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2020 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\TrackingCode\Services;

use Gambio\Admin\Modules\TrackingCode\Model\Collections\TrackingCodeIds;
use Gambio\Admin\Modules\TrackingCode\Model\Exceptions\CreationOfTrackingCodesFailed;
use Gambio\Admin\Modules\TrackingCode\Model\Exceptions\DeletionOfTrackingCodesFailed;
use Gambio\Admin\Modules\TrackingCode\Model\ValueObjects\ParcelServiceDetails;
use Gambio\Admin\Modules\TrackingCode\Model\ValueObjects\TrackingCodeId;

/**
 * Interface TrackingCodeWriteService
 *
 * @package Gambio\Admin\Modules\TrackingCode\Services
 */
interface TrackingCodeWriteService
{
    /**
     * @param int                  $orderId
     * @param string               $code
     * @param ParcelServiceDetails $parcelServiceDetails
     *
     * @return TrackingCodeId
     *
     * @throws CreationOfTrackingCodesFailed
     */
    public function createTrackingCode(
        int $orderId,
        string $code,
        ParcelServiceDetails $parcelServiceDetails
    ): TrackingCodeId;
    
    
    /**
     * @param int[]                  $orderIds
     * @param string[]               $codes
     * @param ParcelServiceDetails[] $parcelServiceDetails
     *
     * @return TrackingCodeIds
     *
     * @throws CreationOfTrackingCodesFailed
     */
    public function createMultipleTrackingCodes(
        array $orderIds,
        array $codes,
        array $parcelServiceDetails
    ): TrackingCodeIds;
    
    
    /**
     * @param int ...$ids
     *
     * @throws DeletionOfTrackingCodesFailed
     */
    public function deleteTrackingCodes(int ...$ids): void;
}