<?php
/* --------------------------------------------------------------
   UserConfigurationServiceProvider.php 2020-02-13
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2020 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\UserConfiguration;

use Doctrine\DBAL\Connection;
use Gambio\Admin\Modules\UserConfiguration\Model\UserId;
use Gambio\Core\Application\DependencyInjection\AbstractServiceProvider;
use Gambio\Core\Application\ValueObjects\UserPreferences;
use Gambio\Admin\Modules\UserConfiguration\CurrentUserConfigurationService as CurrentUserConfigurationServiceImpl;
use Gambio\Admin\Modules\UserConfiguration\Interfaces\CurrentUserConfigurationService;
use Gambio\Admin\Modules\UserConfiguration\Interfaces\UserConfigurationRepository;
use Gambio\Admin\Modules\UserConfiguration\Repository\UserConfigurationReader;
use Gambio\Admin\Modules\UserConfiguration\Repository\UserConfigurationRepository as UserConfigurationRepositoryImpl;
use Gambio\Admin\Modules\UserConfiguration\Repository\UserConfigurationWriter;

/**
 * Class UserConfigurationServiceProvider
 *
 * @package Gambio\Core\ServiceProvider
 */
class UserConfigurationServiceProvider extends AbstractServiceProvider
{
    /**
     * @inheritDoc
     */
    public function provides(): array
    {
        return [
            CurrentUserConfigurationService::class,
            UserConfigurationController::class,
        ];
    }
    
    
    /**
     * @inheritDoc
     */
    public function register(): void
    {
        $this->application->registerShared(UserConfigurationReader::class)->addArgument(Connection::class);
        $this->application->registerShared(UserConfigurationWriter::class)->addArgument(Connection::class);
        
        $this->application->registerShared(UserConfigurationRepository::class, UserConfigurationRepositoryImpl::class)
                          ->addArgument(UserConfigurationReader::class)
                          ->addArgument(UserConfigurationWriter::class);
        
        $this->application->registerShared(CurrentUserConfigurationService::class, CurrentUserConfigurationServiceImpl::class)
                          ->addArgument(UserId::create($this->application->get(UserPreferences::class)->userId()))
                          ->addArgument(UserConfigurationRepository::class);
        
        $this->application->registerShared(UserConfigurationController::class)->addArgument(
            CurrentUserConfigurationService::class
        );
    }
}