<?php
/* --------------------------------------------------------------
   WithdrawalSorting.php 2020-08-26
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2020 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\Withdrawal\App\Data\Filter;

use Doctrine\DBAL\Query\QueryBuilder;
use Gambio\Admin\Modules\Withdrawal\Model\ValueObjects\WithdrawalSorting as WithdrawalSortingInterface;

/**
 * Class WithdrawalSorting
 *
 * @package Gambio\Admin\Modules\Withdrawal\SqlCriteria
 */
class WithdrawalSorting implements WithdrawalSortingInterface
{
    /**
     * @var string
     */
    private $sorting;
    
    /**
     * @var string[]
     */
    private static $attributeColumnMapping = [
        'id'                        => 'withdrawal_id',
        'order.id'                  => 'order_id',
        'order.creationDate'        => 'order_date',
        'order.deliveryDate'        => 'delivery_date',
        'customer.id'               => 'customer_id',
        'customer.gender'           => 'customer_gender',
        'customer.firstName'        => 'customer_firstname',
        'customer.lastName'         => 'customer_lastname',
        'customer.address.street'   => 'customer_street_address',
        'customer.address.postcode' => 'customer_postcode',
        'customer.address.city'     => 'customer_city',
        'customer.address.country'  => 'customer_country',
        'customer.email'            => 'customer_email',
        'date'                      => 'withdrawal_date',
        'content'                   => 'withdrawal_content',
        'createdByAdmin'            => 'created_by_admin',
        'createdOn'                 => 'date_created',
    ];
    
    
    /**
     * WithdrawalSorting constructor.
     *
     * @param string $sorting
     */
    private function __construct(string $sorting)
    {
        $this->sorting = $sorting;
    }
    
    
    /**
     * @param string $sorting
     *
     * @return WithdrawalSorting
     */
    public static function create(string $sorting = ''): WithdrawalSorting
    {
        return new self($sorting);
    }
    
    
    /**
     * @param QueryBuilder $query
     */
    public function applyToQuery(QueryBuilder $query): void
    {
        foreach (explode(',', $this->sorting) as $attribute) {
            if (trim($attribute, '-+') === '') {
                continue;
            }
            
            $order  = (strpos($attribute, '-') === 0) ? 'desc' : 'asc';
            $column = self::$attributeColumnMapping[trim($attribute, '-+')];
            
            $query->addOrderBy($column, $order);
        }
    }
}