<?php
/* --------------------------------------------------------------
   WithdrawalReader.php 2020-08-28
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2019 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\Withdrawal\App\Data;

use Doctrine\DBAL\Connection;
use Gambio\Admin\Modules\Withdrawal\Model\Exceptions\WithdrawalNotFoundException;
use Gambio\Admin\Modules\Withdrawal\Model\ValueObjects\WithdrawalFilters;
use Gambio\Admin\Modules\Withdrawal\Model\ValueObjects\WithdrawalId;
use Gambio\Admin\Modules\Withdrawal\Model\ValueObjects\WithdrawalPagination;
use Gambio\Admin\Modules\Withdrawal\Model\ValueObjects\WithdrawalSorting;

/**
 * Class WithdrawalReader
 *
 * @package Gambio\Admin\Modules\Withdrawal\App\Data
 */
class WithdrawalReader
{
    /**
     * @var Connection
     */
    private $db;
    
    
    /**
     * WithdrawalReader constructor.
     *
     * @param Connection $db
     */
    public function __construct(Connection $db)
    {
        $this->db = $db;
    }
    
    
    /**
     * @param WithdrawalId $id
     *
     * @return array
     *
     * @throws WithdrawalNotFoundException
     */
    public function getWithdrawalDataById(WithdrawalId $id): array
    {
        $withdrawalData = $this->db->createQueryBuilder()
            ->select('*')
            ->from('withdrawals')
            ->where('withdrawal_id = :id')
            ->setParameter('id', $id->value())
            ->execute()
            ->fetch();
        
        if ($withdrawalData === false) {
            throw WithdrawalNotFoundException::forId($id->value());
        }
        
        return $withdrawalData;
    }
    
    
    /**
     * @param WithdrawalFilters|Filter\WithdrawalFilters       $filters
     * @param WithdrawalSorting|Filter\WithdrawalSorting       $sorting
     * @param WithdrawalPagination|Filter\WithdrawalPagination $pagination
     *
     * @return array
     */
    public function getFilteredWithdrawalsData(
        WithdrawalFilters $filters,
        WithdrawalSorting $sorting,
        WithdrawalPagination $pagination
    ): array {
        $query = $this->db->createQueryBuilder()->select('*')->from('withdrawals');
        $filters->applyToQuery($query);
        $sorting->applyToQuery($query);
        $pagination->applyToQuery($query);
        
        return $query->execute()->fetchAll();
    }
    
    
    /**
     * @param WithdrawalFilters|Filter\WithdrawalFilters $filters
     *
     * @return int
     */
    public function getWithdrawalsTotalCount(WithdrawalFilters $filters): int
    {
        $query = $this->db->createQueryBuilder()->select('*')->from('withdrawals');
        $filters->applyToQuery($query);
        
        return $query->execute()->rowCount();
    }
    
    
    /**
     * @return array
     */
    public function getAllWithdrawalsData(): array
    {
        return $this->db->createQueryBuilder()->select('*')->from('withdrawals')->execute()->fetchAll();
    }
}