<?php
/* --------------------------------------------------------------
   WithdrawalService.php 2020-08-26
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2020 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\Withdrawal\App;

use Gambio\Admin\Modules\Withdrawal\App\Data\Filter\WithdrawalFilterFactory;
use Gambio\Admin\Modules\Withdrawal\Model\Collections\Withdrawals;
use Gambio\Admin\Modules\Withdrawal\Services\WithdrawalFilterService as WithdrawalFilterServiceInterface;
use Gambio\Admin\Modules\Withdrawal\Services\WithdrawalRepository;

/**
 * Class WithdrawalService
 *
 * @package Gambio\Admin\Modules\Withdrawal
 */
class WithdrawalFilterService implements WithdrawalFilterServiceInterface
{
    /**
     * @var WithdrawalRepository
     */
    private $repository;
    
    /**
     * @var WithdrawalFilterFactory
     */
    private $factory;
    
    
    /**
     * WithdrawalFilterService constructor.
     *
     * @param WithdrawalRepository    $repository
     * @param WithdrawalFilterFactory $factory
     */
    public function __construct(WithdrawalRepository $repository, WithdrawalFilterFactory $factory)
    {
        $this->repository = $repository;
        $this->factory    = $factory;
    }
    
    
    /**
     * @inheritDoc
     */
    public function filterWithdrawals(array $filters, string $sorting, int $limit = 25, int $offset = 0): Withdrawals
    {
        $filters = array_map([$this, 'mapFilter'], $filters);
        
        return $this->repository->filterWithdrawals($this->factory->createFilters($filters),
                                                    $this->factory->createSorting($sorting),
                                                    $this->factory->createPagination($limit, $offset));
    }
    
    
    /**
     * @inheritDoc
     */
    public function getWithdrawalsTotalCount(array $filters): int
    {
        $filters = array_map([$this, 'mapFilter'], $filters);
        
        return $this->repository->getWithdrawalsTotalCount($this->factory->createFilters($filters));
    }
    
    
    /**
     * @param string $filter
     *
     * @return array
     */
    private function mapFilter(string $filter): array
    {
        $value     = $filter;
        $operation = (strpos($value, '*') !== false) ? 'like' : 'eq';
        if (strpos($filter, '|') !== false) {
            $value     = substr($filter, strpos($filter, '|') + 1);
            $operation = substr($filter, 0, strpos($filter, '|'));
        }
        
        return [
            'value'     => $value,
            'operation' => $operation,
        ];
    }
}