<?php
/* --------------------------------------------------------------
   UpdatedWithdrawalsOrderId.php 2020-08-24
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2020 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\Withdrawal\Model\Events;

use Gambio\Admin\Modules\Withdrawal\Model\ValueObjects\OrderId;
use Gambio\Admin\Modules\Withdrawal\Model\ValueObjects\WithdrawalId;

/**
 * Class UpdatedWithdrawalsOrderId
 *
 * @package Gambio\Admin\Modules\Withdrawal\Model\Events
 * @codeCoverageIgnore
 */
class UpdatedWithdrawalsOrderId
{
    /**
     * @var WithdrawalId
     */
    private $withdrawalId;
    
    /**
     * @var OrderId
     */
    private $orderId;
    
    
    /**
     * DeletedWithdrawal constructor.
     *
     * @param WithdrawalId $withdrawalId
     * @param OrderId      $orderId
     */
    private function __construct(WithdrawalId $withdrawalId, OrderId $orderId)
    {
        $this->withdrawalId = $withdrawalId;
        $this->orderId      = $orderId;
    }
    
    
    /**
     * @param WithdrawalId $withdrawalId
     * @param OrderId      $orderId
     *
     * @return UpdatedWithdrawalsOrderId
     */
    public static function create(WithdrawalId $withdrawalId, OrderId $orderId): UpdatedWithdrawalsOrderId
    {
        return new self($withdrawalId, $orderId);
    }
    
    
    /**
     * @return int
     */
    public function withdrawalId(): int
    {
        $this->withdrawalId->value();
    }
    
    
    /**
     * @return int|null
     */
    public function orderId(): ?int
    {
        $this->orderId->value();
    }
}