/* --------------------------------------------------------------
 gulp_style_edit_jshint.js 2016-09-23
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2016 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

'use strict';

/**
 * Gulp StyleEdit JSHint Task
 *
 * Execute the JSHint directly on the src/StyleEdit3/javascript files.
 *
 * @param {Gulp} gulp Gulp Instance
 * @param {Object} $ Contains the automatically loaded gulp plugins.
 *
 * @return {Function} Returns the gulp task definition.
 */
module.exports = function(gulp, $) {
	function task() {
		const config = {
			jquery: true,
			browser: true,
			node: true,
			camelcase: false,
			eqeqeq: true,
			indent: 4,
			latedef: true,
			maxlen: 120,
			newcap: true,
			quotmark: 'single',
			strict: true,
			undef: true,
			unused: true,
			predef: [
				'StyleEdit',
				'Mustache',
				'IScroll'
			],
			eqnull: true,
			laxbreak: true,
			laxcomma: true,
			validthis: true
		};
		
		return gulp.src([
			'../StyleEdit3/javascript/**/*.js'
		])
			.pipe($.jshint(config))
			.pipe($.jshint.reporter('jshint-stylish'));
	}
	
	task.__description = 'Will perform a JSHint check in the javascript files.';
	
	return task;
};
