/* --------------------------------------------------------------
 gulp_style_edit_vendor.js 2018-10-02
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2016 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

'use strict';

/**
 * Gulp StyleEdit Wire Dependencies Task
 *
 * This task will fetch the main bower files and concatenate and minify them into
 * two new files: the vendor.js and vendor.css. Both files will be placed in the
 * src/StyleEdit/assets directory.
 *
 * Important: Execute this task whenever there is a change in the bower components.
 *
 * @param {Gulp} gulp Gulp Instance
 * @param {Object} $ Contains the automatically loaded gulp plugins.
 *
 * @return {Function} Returns the gulp task definition.
 */
module.exports = function(gulp, $) {
	const vendor = require('../vendor');
	const ftp = require('../ftp');
	
	function task() {
		const packages = [
			'jquery',
			'jquery-ui-dist',
			'mustache',
			'Datejs',
			'bootstrap-material-design',
			'bootstrap-sass',
			'blueimp-file-upload',
			'spectrum-colorpicker',
			'perfect-scrollbar',
			'codemirror'
		];
		const overrides = {
			'spectrum-colorpicker': {
				main: [
					'spectrum.js',
					'spectrum.css'
				]
			},
			'bootstrap-material-design': {
				main: [
					'dist/css/material.css',
					'dist/js/material.js',
					'dist/css/ripples.css',
					'dist/js/ripples.js',
				]
			},
			'bootstrap-sass': {
				main: [
					'assets/javascripts/bootstrap.js'
				]
			},
			'codemirror': {
				main: ['lib/codemirror.js', 'lib/codemirror.css', 'mode/css/css.js', 'mode/sass/sass.js']
			},
			'blueimp-file-upload': {
				main: [
					'js/jquery.iframe-transport.js',
					'js/jquery.fileupload.js'
				]
			},
			'perfect-scrollbar': {
				main: [
					'dist/css/perfect-scrollbar.css',
					'dist/js/perfect-scrollbar.jquery.js'
				]
			},
			'mustache': {
				main: 'mustache.min.js'
			},
			'jquery-ui-dist': {
				main: [
					'jquery-ui.js',
					'jquery-ui.css'
				]
			}
		};
		const js = vendor('js', packages, overrides);
		const css = vendor('css', packages, overrides);
		
		gulp.src(js)
			.pipe($.sourcemaps.init())
			.pipe($.concat('vendor.js'))
			.pipe($.sourcemaps.write())
			.pipe(gulp.dest('../StyleEdit3/assets/javascript'))
			.pipe(ftp.upload('../StyleEdit3/assets/javascript'))
			.pipe($.terser())
			.pipe($.rename({suffix: '.min'}))
			.pipe(gulp.dest('../StyleEdit3/assets/javascript'))
			.pipe(ftp.upload('../StyleEdit3/assets/javascript'));
		
		gulp.src(css)
			.pipe($.sourcemaps.init())
			.pipe($.concat('vendor.css'))
			.pipe($.sourcemaps.write())
			.pipe(gulp.dest('../StyleEdit3/assets/styles'))
			.pipe(ftp.upload('../StyleEdit3/assets/styles'))
			.pipe($.cleanCss())
			.pipe($.rename({suffix: '.min'}))
			.pipe(gulp.dest('../StyleEdit3/assets/styles'))
			.pipe(ftp.upload('../StyleEdit3/assets/styles'));
		
		return gulp.src('node_modules/@fortawesome/fontawesome-free/webfonts/**')
			.pipe(gulp.dest('../StyleEdit3/assets/fonts'));
	}
	
	task.__description = 'Will build vendor.js and vendor.css files in the template assets directory.';
	
	return task;
};
