/* --------------------------------------------------------------
 gulp_template_clean.js 2016-09-23
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2016 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

'use strict';

/**
 * Gulp Template Clean Task
 *
 * This task will remove the admin assets directory entirely.
 *
 * @param {Gulp} gulp Gulp Instance
 * @param {Object} $ Contains the automatically loaded gulp plugins.
 *
 * @return {Function} Returns the gulp task definition.
 */
module.exports = function(gulp, $) {
	const del = require('del');
	const environment = require('../environment');
	const template = environment.getArgument('template') || 'Honeygrid';
	
	function task(async) {
		del.sync([
			`../templates/${template}/assets/fonts/bootstrap`,
			`../templates/${template}/assets/fonts/font-awesome`,
			`../templates/${template}/assets/javascript/engine`,
			`../templates/${template}/assets/javascript/initialize_template.js`,
			`../templates/${template}/assets/javascript/initialize_template.min.js`,
			`../templates/${template}/assets/javascript/template_helpers.js`,
			`../templates/${template}/assets/javascript/template_helpers.min.js`,
			`../templates/${template}/assets/javascript/vendor.js`,
			`../templates/${template}/assets/javascript/vendor.min.js`,
			`../templates/${template}/assets/styles/vendor.css`,
			`../templates/${template}/assets/styles/vendor.min.cs`
		], {force: true});
		async();
	}
	
	task.__description = 'Will remove all the auto-generated assets from the {Template}/assets directory.';
	
	return task;
};
