/* --------------------------------------------------------------
 gulp_template_refresh_cache.js 2018-11-21
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2018 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

'use strict';

/**
 * Remove the required files from the server's cache directory via FTP.
 *
 * This task is useful because it will automatically clear the required cache files so that
 * we always get the new changes while developing Template.
 *
 * Important: This task can only be executed as part of the "dev" task.
 *
 * @param {Gulp} gulp Gulp Instance
 * @param {Object} $ Contains the automatically loaded gulp plugins.
 *
 * @return {Function}
 */
module.exports = function(gulp, $) {
	const fs = require('fs');
	
	function fexists(path) {
		let result = false;
		
		try {
			fs.lstatSync(path);
			result = true;
		} catch (exception) {
			// file does not exist
		}
		
		return result;
	}
	
	function task() {
		const globs = [
			'__dynamics.css',
			'__dynamics_style_edit.css'
		];
		
		try {
			for (let index in globs) {
				if (typeof global.ftpConn !== 'undefined') {
					global.ftpConn.delete(global.ftpConn.config.dest + '/src/cache/' + globs[index], () => {
					});
				} else if (fexists('./src/cache/' + globs[index])) {
					fs.unlinkSync('./src/cache/' + globs[index]);
					$.util.log(`Refresh Cache: Removed ${globs[index]} locally.`);
				}
			}
		} catch (exception) {
			$.util.log($.util.colors.red('Refresh Cache Error: ' + exception));
		}
	}
	
	task.__description = 'Will remove the __dynamics.css (either from FTP server or locally).';
	
	return task;
};
