/* --------------------------------------------------------------
 gulp_template_scripts.js 2016-09-23
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2016 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

'use strict';

const es2015 = require('babel-preset-es2015');

/**
 * Gulp Template Scripts Task
 *
 * This task will concatenate and minify the template JS Engine modules. The final files will be
 * placed in the templates/{Template}/assets/javascript/engine directory.
 *
 * @param {Gulp} gulp Gulp Instance
 * @param {Object} $ Contains the automatically loaded gulp plugins.
 *
 * @return {Function} Returns the gulp task definition.
 */
module.exports = function(gulp, $) {
	const fs = require('fs');
	const path = require('path');
	const ftp = require('../ftp');
	const environment = require('../environment');
	const template = environment.getArgument('template') || 'Honeygrid';
	
	function isDir(file) {
		return fs.lstatSync(file.path).isDirectory();
	}
	
	function isHtml(file) {
		return (path.extname(file.path) === '.html');
	}
	
	function task() {
		gulp.src([
			`../templates/${template}/javascript/initialize_template.js`,
			`../templates/${template}/javascript/template_helpers.js`,
		])
			.pipe($.sourcemaps.init())
			.pipe($.babel({presets: [es2015]}))
			.pipe($.sourcemaps.write())
			.pipe(gulp.dest(`../templates/${template}/assets/javascript`))
			.pipe(ftp.upload(`../templates/${template}/assets/javascript`))
			.pipe($.terser().on('error', $.util.log))
			.pipe($.rename({suffix: '.min'}))
			.pipe(gulp.dest(`../templates/${template}/assets/javascript`))
			.pipe(ftp.upload(`../templates/${template}/assets/javascript`));
		
		return gulp.src(`../templates/${template}/javascript/engine/**`)
			.pipe($.changed(`../templates/${template}/assets/javascript/engine`))
			.pipe($.sourcemaps.init())
			.pipe($.babel({presets: [es2015]}))
			.pipe($.sourcemaps.write())
			.pipe(gulp.dest(`../templates/${template}/assets/javascript/engine`))
			.pipe(ftp.upload(`../templates/${template}/assets/javascript/engine`))
			.pipe($.ignore.exclude(isDir))
			.pipe($.ignore.exclude(isHtml))
			.pipe($.terser().on('error', $.util.log))
			.pipe($.rename({suffix: '.min'}))
			.pipe(gulp.dest(`../templates/${template}/assets/javascript/engine`))
			.pipe(ftp.upload(`../templates/${template}/assets/javascript/engine`));
	}
	
	task.__description = 'Will only build the template JavaScript files.';
	
	return task;
};
