/* --------------------------------------------------------------
 gulp_template_watch.js 2016-09-23
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2016 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

'use strict';

const enrivonment = require('../environment');
const template = enrivonment.getArgument('template') || 'Honeygrid';

/**
 * Gulp Template Watch Task
 *
 * This task will place a watcher upon the template scripts and styles and it will execute the
 * required operations whenever a file is changed.
 *
 * @param {Gulp} gulp Gulp Instance
 * @param {Object} $ Contains the automatically loaded gulp plugins.
 *
 * @return {Function} Returns the gulp task definition.
 */
module.exports = function(gulp, $) {
	function task() {
		gulp.watch([
				`../templates/${template}/javascript/**/*.js`
			],
			['template:scripts']);
		
		gulp.watch([
				`../templates/${template}/styles/**/*.scss`,
				`../templates/${template}/styles/**/*.css`
			],
			['template:refresh_cache']);
		
		gulp.watch([
				`../templates/${template}/boxes/**/*.html`,
				`../templates/${template}/module/**/*.html`,
				`../templates/${template}/snippets/**/*.html`
			],
			['template:templates']);
	}
	
	task.__description = 'Will start the file watchers for the template files (prefer the "dev" task for development).';
	
	return task;
};
